==> react-ui-5.0.0.tgz: package/TabLayout.js <==
/******/ (() => {
    // webpackBootstrap
    /******/ "use strict";
    /******/ // The require scope
    /******/    var e = {};
    /******/
    /************************************************************************/
    /******/ /* webpack/runtime/compat get default export */
    /******/    (() => {
        /******/ // getDefaultExport function for compatibility with non-harmony modules
        /******/ e.n = t => {
            /******/ var n = t && t.__esModule ? 
            /******/ () => t["default"]
            /******/ : () => t
            /******/;
            e.d(n, {
                a: n
            });
            /******/            return n;
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/define property getters */
    /******/    (() => {
        /******/ // define getter functions for harmony exports
        /******/ e.d = (t, n) => {
            /******/ for (var r in n) {
                /******/ if (e.o(n, r) && !e.o(t, r)) {
                    /******/ Object.defineProperty(t, r, {
                        enumerable: true,
                        get: n[r]
                    });
                    /******/                }
                /******/            }
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/hasOwnProperty shorthand */
    /******/    (() => {
        /******/ e.o = (e, t) => Object.prototype.hasOwnProperty.call(e, t)
        /******/;
    })();
    /******/
    /******/ /* webpack/runtime/make namespace object */
    /******/    (() => {
        /******/ // define __esModule on exports
        /******/ e.r = e => {
            /******/ if (typeof Symbol !== "undefined" && Symbol.toStringTag) {
                /******/ Object.defineProperty(e, Symbol.toStringTag, {
                    value: "Module"
                });
                /******/            }
            /******/            Object.defineProperty(e, "__esModule", {
                value: true
            });
            /******/        };
        /******/    })();
    /******/
    /************************************************************************/    var t = {};
    // ESM COMPAT FLAG
        e.r(t);
    // EXPORTS
        e.d(t, {
        Panel: () => /* reexport */ S,
        default: () => /* reexport */ M
    });
    // CONCATENATED MODULE: external "react"
    const n = require("react");
    var r =  e.n(n);
    // CONCATENATED MODULE: external "prop-types"
    const a = require("prop-types");
    var l =  e.n(a);
    // CONCATENATED MODULE: external "@splunk/ui-utils/id"
    const o = require("@splunk/ui-utils/id");
    // CONCATENATED MODULE: external "@splunk/react-ui/TabBar"
    const i = require("@splunk/react-ui/TabBar");
    var u =  e.n(i);
    // CONCATENATED MODULE: external "@splunk/react-ui/useControlled"
    const c = require("@splunk/react-ui/useControlled");
    var s =  e.n(c);
    // CONCATENATED MODULE: external "lodash/omit"
    const d = require("lodash/omit");
    var f =  e.n(d);
    // CONCATENATED MODULE: external "styled-components"
    const v = require("styled-components");
    var p =  e.n(v);
    // CONCATENATED MODULE: external "@splunk/themes"
    const b = require("@splunk/themes");
    // CONCATENATED MODULE: ./src/TabLayout/TabLayoutStyles.ts
    var y = p().div.withConfig({
        displayName: "TabLayoutStyles__StyledPanel",
        componentId: "lf0quy-0"
    })([ "", " ", "" ], b.mixins.reset("block"), (function(e) {
        var t = e.$inset;
        return t && (0, v.css)([ "padding:", ";" ], b.variables.spacingLarge);
    }));
    var m = p().div.withConfig({
        displayName: "TabLayoutStyles__Styled",
        componentId: "lf0quy-1"
    })([ "text-align:center;margin-top:", ";", "" ], b.variables.spacingLarge, (function(e) {
        var t = e.$layout;
        return t === "vertical" && (0, v.css)([ "display:flex;& > [role='tablist']{flex:0 0 auto;}& > ", "{width:100%;}" ], /* sc-sel */ y);
    }));
    // CONCATENATED MODULE: ./src/TabLayout/Panel.tsx
    function g() {
        return g = Object.assign ? Object.assign.bind() : function(e) {
            for (var t = 1; t < arguments.length; t++) {
                var n = arguments[t];
                for (var r in n) {
                    ({}).hasOwnProperty.call(n, r) && (e[r] = n[r]);
                }
            }
            return e;
        }, g.apply(null, arguments);
    }
    function h(e, t) {
        if (null == e) return {};
        var n, r, a = P(e, t);
        if (Object.getOwnPropertySymbols) {
            var l = Object.getOwnPropertySymbols(e);
            for (r = 0; r < l.length; r++) {
                n = l[r], t.includes(n) || {}.propertyIsEnumerable.call(e, n) && (a[n] = e[n]);
            }
        }
        return a;
    }
    function P(e, t) {
        if (null == e) return {};
        var n = {};
        for (var r in e) {
            if ({}.hasOwnProperty.call(e, r)) {
                if (t.includes(r)) continue;
                n[r] = e[r];
            }
        }
        return n;
    }
    var O = {
        children: l().node,
        count: l().number,
        disabled: l().bool,
        elementRef: l().oneOfType([ l().func, l().object ]),
        icon: l().node,
        inset: l().bool,
        label: l().oneOfType([ l().string, l().element ]),
        panelId: l().string.isRequired,
        tooltip: l().node
    };
    function I(e) {
        var t = e.children, n = e.disabled, a = n === void 0 ? false : n, l = e.elementRef, o = e.inset, i = o === void 0 ? true : o, u = e.panelId, c = h(e, [ "children", "disabled", "elementRef", "inset", "panelId" ]);
        // @docs-props-type PanelPropsBase
                
        return r().createElement(y, g({
            $inset: i,
            "data-test-panel-id": u,
            "data-test": "panel",
            ref: l,
            role: "tabpanel"
        }, f()(c, [ "icon", "label", "tooltip" ])), t);
    }
    I.propTypes = O;
    /* harmony default export */    const S = I;
    // CONCATENATED MODULE: ./src/TabLayout/TabLayout.tsx
    function T() {
        return T = Object.assign ? Object.assign.bind() : function(e) {
            for (var t = 1; t < arguments.length; t++) {
                var n = arguments[t];
                for (var r in n) {
                    ({}).hasOwnProperty.call(n, r) && (e[r] = n[r]);
                }
            }
            return e;
        }, T.apply(null, arguments);
    }
    function j(e, t) {
        return x(e) || C(e, t) || A(e, t) || w();
    }
    function w() {
        throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
    }
    function A(e, t) {
        if (e) {
            if ("string" == typeof e) return q(e, t);
            var n = {}.toString.call(e).slice(8, -1);
            return "Object" === n && e.constructor && (n = e.constructor.name), "Map" === n || "Set" === n ? Array.from(e) : "Arguments" === n || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n) ? q(e, t) : void 0;
        }
    }
    function q(e, t) {
        (null == t || t > e.length) && (t = e.length);
        for (var n = 0, r = Array(t); n < t; n++) {
            r[n] = e[n];
        }
        return r;
    }
    function C(e, t) {
        var n = null == e ? null : "undefined" != typeof Symbol && e[Symbol.iterator] || e["@@iterator"];
        if (null != n) {
            var r, a, l, o, i = [], u = !0, c = !1;
            try {
                if (l = (n = n.call(e)).next, 0 === t) {
                    if (Object(n) !== n) return;
                    u = !1;
                } else for (;!(u = (r = l.call(n)).done) && (i.push(r.value), i.length !== t); u = !0) {
                }
            } catch (e) {
                c = !0, a = e;
            } finally {
                try {
                    if (!u && null != n["return"] && (o = n["return"](), Object(o) !== o)) return;
                } finally {
                    if (c) throw a;
                }
            }
            return i;
        }
    }
    function x(e) {
        if (Array.isArray(e)) return e;
    }
    function E(e, t) {
        if (null == e) return {};
        var n, r, a = _(e, t);
        if (Object.getOwnPropertySymbols) {
            var l = Object.getOwnPropertySymbols(e);
            for (r = 0; r < l.length; r++) {
                n = l[r], t.includes(n) || {}.propertyIsEnumerable.call(e, n) && (a[n] = e[n]);
            }
        }
        return a;
    }
    function _(e, t) {
        if (null == e) return {};
        var n = {};
        for (var r in e) {
            if ({}.hasOwnProperty.call(e, r)) {
                if (t.includes(r)) continue;
                n[r] = e[r];
            }
        }
        return n;
    }
    /** @public */    var k = {
        autoActivate: l().bool,
        activePanelId: l().string,
        children: l().node,
        defaultActivePanelId: l().string,
        elementRef: l().oneOfType([ l().func, l().object ]),
        iconPosition: l().oneOf([ "above", "left" ]),
        layout: l().oneOf([ "horizontal", "vertical" ]),
        maxTabWidth: l().number,
        onChange: l().func
    };
    /**
 * The `TabLayout` is a group of managed `Panels`. Only one panel can be open at a time.
 * `TabLayout` supports both the controlled and uncontrolled patterns.
 */    function R(e) {
        var t = e.autoActivate, a = e.activePanelId, l = e.children, i = e.defaultActivePanelId, c = e.elementRef, d = e.iconPosition, f = e.layout, v = f === void 0 ? "horizontal" : f, p = e.maxTabWidth, b = e.onChange, y = E(e, [ "autoActivate", "activePanelId", "children", "defaultActivePanelId", "elementRef", "iconPosition", "layout", "maxTabWidth", "onChange" ]);
        // @docs-props-type TabLayoutPropsBase
                var g = s()({
            componentName: "TabLayout",
            /* eslint-disable-next-line prefer-rest-params */
            componentProps: arguments[0],
            // see SUI-7028
            defaultValuePropName: "defaultActivePanelId",
            valuePropName: "activePanelId"
        });
        var h = (0, n.useState)(), P = j(h, 2), O = P[0], I = P[1];
        var S = (0, n.useState)(g ? undefined : i), w = j(S, 2), A = w[0], q = w[1];
 // Could use activePanelIdProp for isControlled route but chose not to b/c we always favor direct prop access in below logic in that scenario
                var C = (0, n.useMemo)((function() {
            return g ? a : A;
        }), [ g, a, A ]);
        var x = (0, n.useState)((0, o.createGUID)()), _ = j(x, 1), k = _[0];
        var R = (0, n.useCallback)((function(e, t) {
            var n = t.selectedTabId;
            if (!g) {
                q(n);
            }
            b === null || b === void 0 ? void 0 : b(e, {
                activePanelId: n
            });
        }), [ g, b ]);
        var M = (0, n.useMemo)((function() {
            var e = null;
            var t = n.Children.toArray(l).filter(n.isValidElement).map((function(t) {
                var a = t.props;
                var l = "".concat(k, "-").concat(a.panelId);
                var o = "".concat(k, "-").concat(a.panelId, "-tab");
                if (a.panelId === C) {
                    e =  (0, n.cloneElement)(t, {
                        "aria-labelledby": o,
                        id: l
                    });
                }
                var i = {};
                // tell TS that PanelProps can contain `data-title`
                                var c = a["data-title"];
                if (c != null) {
                    i["data-title"] = c;
                }
                
                return r().createElement(u().Tab, T({
                    count: a.count,
                    icon: a.icon,
                    key: a.panelId,
                    label: a.label,
                    tabId: a.panelId,
                    id: o,
                    ariaControls: l,
                    tooltip: a.tooltip,
                    disabled: a.disabled
                }, i));
            }));
            I(e);
            return t;
        }), [ C, l, k ]);
        (0, n.useEffect)((function() {
            if (false) {}
        }), [ O ]);
        
        return r().createElement(m, T({
            "data-test-active-panel-id": C,
            "data-test": "tab-layout",
            ref: c,
            $layout: v
        }, y),  r().createElement(u(), {
            autoActivate: t,
            activeTabId: C,
            iconPosition: d,
            layout: v,
            maxTabWidth: p,
            onChange: R
        }, M), O);
    }
    R.Panel = S;
    R.propTypes = k;
    /* harmony default export */    const M = R;
    // CONCATENATED MODULE: ./src/TabLayout/index.ts
    module.exports = t;
    /******/})();

==> react-ui-5.1.0.tgz: package/TabLayout.js <==
/******/ (() => {
    // webpackBootstrap
    /******/ "use strict";
    /******/ // The require scope
    /******/    var e = {};
    /******/
    /************************************************************************/
    /******/ /* webpack/runtime/compat get default export */
    /******/    (() => {
        /******/ // getDefaultExport function for compatibility with non-harmony modules
        /******/ e.n = t => {
            /******/ var n = t && t.__esModule ? 
            /******/ () => t["default"]
            /******/ : () => t
            /******/;
            e.d(n, {
                a: n
            });
            /******/            return n;
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/define property getters */
    /******/    (() => {
        /******/ // define getter functions for harmony exports
        /******/ e.d = (t, n) => {
            /******/ for (var r in n) {
                /******/ if (e.o(n, r) && !e.o(t, r)) {
                    /******/ Object.defineProperty(t, r, {
                        enumerable: true,
                        get: n[r]
                    });
                    /******/                }
                /******/            }
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/hasOwnProperty shorthand */
    /******/    (() => {
        /******/ e.o = (e, t) => Object.prototype.hasOwnProperty.call(e, t)
        /******/;
    })();
    /******/
    /******/ /* webpack/runtime/make namespace object */
    /******/    (() => {
        /******/ // define __esModule on exports
        /******/ e.r = e => {
            /******/ if (typeof Symbol !== "undefined" && Symbol.toStringTag) {
                /******/ Object.defineProperty(e, Symbol.toStringTag, {
                    value: "Module"
                });
                /******/            }
            /******/            Object.defineProperty(e, "__esModule", {
                value: true
            });
            /******/        };
        /******/    })();
    /******/
    /************************************************************************/    var t = {};
    // ESM COMPAT FLAG
        e.r(t);
    // EXPORTS
        e.d(t, {
        Panel: () => /* reexport */ S,
        default: () => /* reexport */ M
    });
    // CONCATENATED MODULE: external "react"
    const n = require("react");
    var r =  e.n(n);
    // CONCATENATED MODULE: external "prop-types"
    const a = require("prop-types");
    var l =  e.n(a);
    // CONCATENATED MODULE: external "@splunk/react-ui/TabBar"
    const o = require("@splunk/react-ui/TabBar");
    var i =  e.n(o);
    // CONCATENATED MODULE: external "@splunk/react-ui/useControlled"
    const u = require("@splunk/react-ui/useControlled");
    var c =  e.n(u);
    // CONCATENATED MODULE: external "@splunk/ui-utils/id"
    const s = require("@splunk/ui-utils/id");
    // CONCATENATED MODULE: external "lodash/omit"
    const d = require("lodash/omit");
    var f =  e.n(d);
    // CONCATENATED MODULE: external "styled-components"
    const v = require("styled-components");
    var p =  e.n(v);
    // CONCATENATED MODULE: external "@splunk/themes"
    const b = require("@splunk/themes");
    // CONCATENATED MODULE: ./src/TabLayout/TabLayoutStyles.ts
    var y = p().div.withConfig({
        displayName: "TabLayoutStyles__StyledPanel",
        componentId: "lf0quy-0"
    })([ "", " ", "" ], b.mixins.reset("block"), (function(e) {
        var t = e.$inset;
        return t && (0, v.css)([ "padding:", ";" ], b.variables.spacingLarge);
    }));
    var m = p().div.withConfig({
        displayName: "TabLayoutStyles__Styled",
        componentId: "lf0quy-1"
    })([ "text-align:center;margin-top:", ";", "" ], b.variables.spacingLarge, (function(e) {
        var t = e.$layout;
        return t === "vertical" && (0, v.css)([ "display:flex;& > [role='tablist']{flex:0 0 auto;}& > ", "{width:100%;}" ], /* sc-sel */ y);
    }));
    // CONCATENATED MODULE: ./src/TabLayout/Panel.tsx
    function g() {
        return g = Object.assign ? Object.assign.bind() : function(e) {
            for (var t = 1; t < arguments.length; t++) {
                var n = arguments[t];
                for (var r in n) {
                    ({}).hasOwnProperty.call(n, r) && (e[r] = n[r]);
                }
            }
            return e;
        }, g.apply(null, arguments);
    }
    function h(e, t) {
        if (null == e) return {};
        var n, r, a = P(e, t);
        if (Object.getOwnPropertySymbols) {
            var l = Object.getOwnPropertySymbols(e);
            for (r = 0; r < l.length; r++) {
                n = l[r], t.includes(n) || {}.propertyIsEnumerable.call(e, n) && (a[n] = e[n]);
            }
        }
        return a;
    }
    function P(e, t) {
        if (null == e) return {};
        var n = {};
        for (var r in e) {
            if ({}.hasOwnProperty.call(e, r)) {
                if (t.includes(r)) continue;
                n[r] = e[r];
            }
        }
        return n;
    }
    var O = {
        children: l().node,
        count: l().number,
        disabled: l().bool,
        elementRef: l().oneOfType([ l().func, l().object ]),
        icon: l().node,
        inset: l().bool,
        label: l().oneOfType([ l().string, l().element ]),
        panelId: l().string.isRequired,
        tooltip: l().node
    };
    function I(e) {
        var t = e.children, n = e.disabled, a = n === void 0 ? false : n, l = e.elementRef, o = e.inset, i = o === void 0 ? true : o, u = e.panelId, c = h(e, [ "children", "disabled", "elementRef", "inset", "panelId" ]);
        // @docs-props-type PanelPropsBase
                
        return r().createElement(y, g({
            $inset: i,
            "data-test-panel-id": u,
            "data-test": "panel",
            ref: l,
            role: "tabpanel"
        }, f()(c, [ "icon", "label", "tooltip" ])), t);
    }
    I.propTypes = O;
    /* harmony default export */    const S = I;
    // CONCATENATED MODULE: ./src/TabLayout/TabLayout.tsx
    function T() {
        return T = Object.assign ? Object.assign.bind() : function(e) {
            for (var t = 1; t < arguments.length; t++) {
                var n = arguments[t];
                for (var r in n) {
                    ({}).hasOwnProperty.call(n, r) && (e[r] = n[r]);
                }
            }
            return e;
        }, T.apply(null, arguments);
    }
    function j(e, t) {
        return x(e) || C(e, t) || A(e, t) || w();
    }
    function w() {
        throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
    }
    function A(e, t) {
        if (e) {
            if ("string" == typeof e) return q(e, t);
            var n = {}.toString.call(e).slice(8, -1);
            return "Object" === n && e.constructor && (n = e.constructor.name), "Map" === n || "Set" === n ? Array.from(e) : "Arguments" === n || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n) ? q(e, t) : void 0;
        }
    }
    function q(e, t) {
        (null == t || t > e.length) && (t = e.length);
        for (var n = 0, r = Array(t); n < t; n++) {
            r[n] = e[n];
        }
        return r;
    }
    function C(e, t) {
        var n = null == e ? null : "undefined" != typeof Symbol && e[Symbol.iterator] || e["@@iterator"];
        if (null != n) {
            var r, a, l, o, i = [], u = !0, c = !1;
            try {
                if (l = (n = n.call(e)).next, 0 === t) {
                    if (Object(n) !== n) return;
                    u = !1;
                } else for (;!(u = (r = l.call(n)).done) && (i.push(r.value), i.length !== t); u = !0) {
                }
            } catch (e) {
                c = !0, a = e;
            } finally {
                try {
                    if (!u && null != n["return"] && (o = n["return"](), Object(o) !== o)) return;
                } finally {
                    if (c) throw a;
                }
            }
            return i;
        }
    }
    function x(e) {
        if (Array.isArray(e)) return e;
    }
    function E(e, t) {
        if (null == e) return {};
        var n, r, a = _(e, t);
        if (Object.getOwnPropertySymbols) {
            var l = Object.getOwnPropertySymbols(e);
            for (r = 0; r < l.length; r++) {
                n = l[r], t.includes(n) || {}.propertyIsEnumerable.call(e, n) && (a[n] = e[n]);
            }
        }
        return a;
    }
    function _(e, t) {
        if (null == e) return {};
        var n = {};
        for (var r in e) {
            if ({}.hasOwnProperty.call(e, r)) {
                if (t.includes(r)) continue;
                n[r] = e[r];
            }
        }
        return n;
    }
    /** @public */    var k = {
        autoActivate: l().bool,
        activePanelId: l().string,
        children: l().node,
        defaultActivePanelId: l().string,
        elementRef: l().oneOfType([ l().func, l().object ]),
        iconPosition: l().oneOf([ "above", "left" ]),
        layout: l().oneOf([ "horizontal", "vertical" ]),
        maxTabWidth: l().number,
        onChange: l().func
    };
    /**
 * The `TabLayout` is a group of managed `Panels`. Only one panel can be open at a time.
 * `TabLayout` supports both the controlled and uncontrolled patterns.
 */    function R(e) {
        var t = e.autoActivate, a = e.activePanelId, l = e.children, o = e.defaultActivePanelId, u = e.elementRef, d = e.iconPosition, f = e.layout, v = f === void 0 ? "horizontal" : f, p = e.maxTabWidth, b = e.onChange, y = E(e, [ "autoActivate", "activePanelId", "children", "defaultActivePanelId", "elementRef", "iconPosition", "layout", "maxTabWidth", "onChange" ]);
        // @docs-props-type TabLayoutPropsBase
                var g = c()({
            componentName: "TabLayout",
            /* eslint-disable-next-line prefer-rest-params */
            componentProps: arguments[0],
            // see SUI-7028
            defaultValuePropName: "defaultActivePanelId",
            valuePropName: "activePanelId"
        });
        var h = (0, n.useState)(), P = j(h, 2), O = P[0], I = P[1];
        var S = (0, n.useState)(g ? undefined : o), w = j(S, 2), A = w[0], q = w[1];
 // Could use activePanelIdProp for isControlled route but chose not to b/c we always favor direct prop access in below logic in that scenario
                var C = (0, n.useMemo)((function() {
            return g ? a : A;
        }), [ g, a, A ]);
        var x = (0, n.useState)((0, s.createGUID)()), _ = j(x, 1), k = _[0];
        var R = (0, n.useCallback)((function(e, t) {
            var n = t.selectedTabId;
            if (!g) {
                q(n);
            }
            b === null || b === void 0 ? void 0 : b(e, {
                activePanelId: n
            });
        }), [ g, b ]);
        var M = (0, n.useMemo)((function() {
            var e = null;
            var t = n.Children.toArray(l).filter(n.isValidElement).map((function(t) {
                var a = t.props;
                var l = "".concat(k, "-").concat(a.panelId);
                var o = "".concat(k, "-").concat(a.panelId, "-tab");
                if (a.panelId === C) {
                    e =  (0, n.cloneElement)(t, {
                        "aria-labelledby": o,
                        id: l
                    });
                }
                var u = {};
                // tell TS that PanelProps can contain `data-title`
                                var c = a["data-title"];
                if (c != null) {
                    u["data-title"] = c;
                }
                
                return r().createElement(i().Tab, T({
                    count: a.count,
                    icon: a.icon,
                    key: a.panelId,
                    label: a.label,
                    tabId: a.panelId,
                    id: o,
                    ariaControls: l,
                    tooltip: a.tooltip,
                    disabled: a.disabled
                }, u));
            }));
            I(e);
            return t;
        }), [ C, l, k ]);
        (0, n.useEffect)((function() {
            if (false) {}
        }), [ O ]);
        
        return r().createElement(m, T({
            "data-test-active-panel-id": C,
            "data-test": "tab-layout",
            ref: u,
            $layout: v
        }, y),  r().createElement(i(), {
            autoActivate: t,
            activeTabId: C,
            iconPosition: d,
            layout: v,
            maxTabWidth: p,
            onChange: R
        }, M), O);
    }
    R.Panel = S;
    R.propTypes = k;
    /* harmony default export */    const M = R;
    // CONCATENATED MODULE: ./src/TabLayout/index.ts
    module.exports = t;
    /******/})();
